/*------------------------------------------------------------------------------
 * MDK Middleware - Component ::USB:Device
 * Copyright (c) 2004-2019 Arm Limited (or its affiliates). All rights reserved.
 *------------------------------------------------------------------------------
 * Name:    HID.c
 * Purpose: USB Device - Human Interface Device example
 *----------------------------------------------------------------------------*/

#include "main.h"
#include "rl_usb.h"                     // Keil.MDK-Pro::USB:CORE

#include "Board_Joystick.h"             // ::Board Support:Joystick
#include "GLCD_Config.h"                // Keil.MCB54110::Board Support:Graphic LCD
#include "GLCD_Fonts.h"


/* Main stack size must be multiple of 8 Bytes */
#define APP_MAIN_STK_SZ (1024U)
static uint64_t app_main_stk[APP_MAIN_STK_SZ / 8];
const osThreadAttr_t app_main_attr = {
  .stack_mem  = &app_main_stk[0],
  .stack_size = sizeof(app_main_stk)
};

/*------------------------------------------------------------------------------
 *        Application
 *----------------------------------------------------------------------------*/
__NO_RETURN void app_main (void *arg) {
  uint8_t joy, last_joy = 0;

  (void)arg;

  GLCD_SetBackgroundColor (GLCD_COLOR_BLUE);
  GLCD_SetForegroundColor (GLCD_COLOR_WHITE);
  GLCD_ClearScreen        ();
  GLCD_SetFont            (&GLCD_Font_16x24);
  GLCD_DrawString         (0U, 0U*24U, "    USB Device      ");
  GLCD_DrawString         (0U, 1U*24U, "    HID Class       ");
  GLCD_DrawString         (0U, 2U*24U, "    HID Example     ");
  GLCD_DrawString         (0U, 4U*24U, " USB0: HID0         ");
  GLCD_DrawString         (0U, 8U*24U, "  Keil Tools by ARM ");
  GLCD_DrawString         (0U, 9U*24U, "    www.keil.com    ");

  USBD_Initialize         (0U);         /* USB Device 0 Initialization */
  USBD_Connect            (0U);         /* USB Device 0 Connect */

  while (1) {                           /* Loop forever */
    joy = (uint8_t)(Joystick_GetState ());
    if (joy != last_joy) {
      last_joy = joy;
      USBD_HID_GetReportTrigger(0, 0, &joy, 1);
    }
    osDelay(100U);                       /* 100 ms delay for sampling buttons  */
  }
}
